#!/usr/bin/env python3

import matplotlib.pyplot as plt
import numpy as np
import glob, os, sys
import itertools

## pass in caselist
padlist=sys.argv[1:]

#import matplotlib
#matplotlib.rcParams.update({'font.size': 16})
params={
          'text.latex.preamble' : [r'\usepackage{amsmath}'],
                'font.size':14,
                    }
plt.rcParams.update(params)
plt.figure(figsize=(10, 6))

ncases=len(padlist)
iscale = 0

#colormap=plt.cm.rainbow
colormap=plt.cm.tab10  ## depending how many cases there are
#colormap=plt.cm.tab20
#colormap=plt.cm.tab20b
#colormap=plt.cm.tab20c

color = iter(colormap(np.linspace(0, 1, colormap.N)))
color = itertools.cycle(color)

paddleArea = 0.975*0.665 ## width * height
## Area is constant for all aspect ration studies
## A2  is 1.13875* 0.5695
## A5  is 1.8005 * 0.3601
## A10 is 2.546  * 0.2546

rho=1000.0

## force data is 10 columns, onreally reall care about time and total_x
## Time            (total_x total_y total_z)   (pressure_x pressure_y pressure_z)  (viscous_x viscous_y viscous_z)
ncolumns=10

CdList=[]
texlist=[]

with open('template.tex') as fin:
  texdata=fin.read()

for padtype in padlist:
  print ('Analyzing design '+padtype[1:])

  ## make labels
  if padtype == '_3flaps':
      texlist.append(r'''3 paddles''')
  elif padtype == '_5flaps':
      texlist.append(r'''5 paddles''')
  elif padtype == '_3flap-gap':
      texlist.append(r'''3 paddles, Gap''')
  elif padtype == '_3flap-2xgap':
      texlist.append(r'''3 paddles, 2xGap''')
  elif padtype == '_tank-3flap':
      texlist.append(r'''3 paddles, Trapezoidal''')
  elif padtype == '_3flaps-pours':
      texlist.append(r'''3 paddles, Porous''')
  elif padtype == '_3flap-gap-nozzles':
      texlist.append(r'''3 paddles, Gap, Nozzle''')
  elif padtype == '_3flap-gap-a2':
      texlist.append(r'''3 paddles, Aspect 2.0''')
  elif padtype == '_3flap-gap-a5':
      texlist.append(r'''3 paddles, Aspect 5.0''')
  elif padtype == '_3flap-gap-a10':
      texlist.append(r'''3 paddles, Aspect 10.0''')
  elif padtype == '_5flap-gap-a10':
      texlist.append(r'''5 paddles, Aspect 10.0''')
  elif padtype == '_3flap-gap-a10-30deg-pitch':
      texlist.append(r'''3 paddles, Aspect 10.0, Pitch $30^{\circ}$''')
  elif padtype == '_5flap-gap-a10-30deg-pitch':
      texlist.append(r'''5 paddles, Aspect 10.0, Pitch $30^{\circ}$''')
  elif padtype == '_3flap-gap-15deg-yaw':
      texlist.append(r'''3 paddles, Yaw $15^{\circ}$''')
  elif padtype == '_3flap-gap-15deg-yaw_0.1x':
      texlist.append(r'''3 paddles, Yaw $15^{\circ}$ $0.1\times$ Scale''')
  elif padtype == '_3flap-gap-15deg-yaw_10x':
      texlist.append(r'''3 paddles, Yaw $15^{\circ}$ $10\times$ Scale''')
  elif padtype == '_3flap-gap-30deg-yaw':
      texlist.append(r'''3 paddles, Yaw $30^{\circ}$''')
  elif padtype == '_3flap-gap-15deg-pitch':
      texlist.append(r'''3 paddles, Pitch $15^{\circ}$''')
  elif padtype == '_3flap-gap-15deg-pitch-2mFloor':
      texlist.append(r'''3 paddles, Pitch $15^{\circ}$ Floor''')
  elif padtype == '_3flap-gap-30deg-pitch':
      texlist.append(r'''3 paddles, Pitch $30^{\circ}$''')
  elif padtype == '_3flap-gap-35deg-pitch':
      texlist.append(r'''3 paddles, Pitch $35^{\circ}$''')
  elif padtype == '_3flap-gap-40deg-pitch':
      texlist.append(r'''3 paddles, Pitch $40^{\circ}$''')
  elif padtype == '_3flap-gap-45deg-pitch':
      texlist.append(r'''3 paddles, Pitch $45^{\circ}$''')
  elif padtype == '_3flap-gap-60deg-pitch':
      texlist.append(r'''3 paddles, Pitch $60^{\circ}$''')
  else:
      print("Paddle type ",padtype," unknown")
      sys.exit(1)
#


  if '-30deg-pitch' in padtype:
    angle=30.0
    rads=angle*np.pi/180.0
    nx =  np.cos(rads)
    ny = -np.sin(rads)
    nz =  0.0
    if '5flap' in padtype:
        info=[\
        ['forces1f', 'Front 1', [ nx, ny, nz ]],
        ['forces1b', 'Back 1' , [ nx, ny, nz ]],
        ['forces2f', 'Front 2', [ nx, ny, nz ]],  ## don't exist in 3 paddle cases
        ['forces2b', 'Back 2' , [ nx, ny, nz ]],
        ['forces3f', 'Front 3', [ nx, ny, nz ]],
        ['forces3b', 'Back 3' , [ nx, ny, nz ]],
        ['forces4f', 'Front 4', [ nx, ny, nz ]],
        ['forces4b', 'Back 4' , [ nx, ny, nz ]],
        ['forces5f', 'Front 5', [ nx, ny, nz ]],
        ['forces5b', 'Back 5' , [ nx, ny, nz ]],
        ]
        symscale=[2,2,0,0,0,2]
        vellist=[ '1.00', '2.00' ]
        if '-a10' in padtype:
            caseleg=r'''5 Paddles, $30^{\circ}$ Pitch, Aspect 10'''          # legend for case
        else:
            caseleg=r'''5 Paddles, $30^{\circ}$ Pitch'''          # legend for case
    else:
        info=[\
        ['forces1f', 'Front 1', [ nx, ny, nz ]],
        ['forces1b', 'Back 1' , [ nx, ny, nz ]],
       #['forces2f', 'Front 2', [ nx, ny, nz ]],  ## don't exist in 3 paddle cases
       #['forces2b', 'Back 2' , [ nx, ny, nz ]],
        ['forces3f', 'Front 3', [ nx, ny, nz ]],
        ['forces3b', 'Back 3' , [ nx, ny, nz ]],
       #['forces4f', 'Front 4', [ nx, ny, nz ]],
       #['forces4b', 'Back 4' , [ nx, ny, nz ]],
        ['forces5f', 'Front 5', [ nx, ny, nz ]],
        ['forces5b', 'Back 5' , [ nx, ny, nz ]],
        ]
        symscale=[2,2,0,0,0,2]
        vellist=[ '1.00', '2.00' ]
        if '-a10' in padtype:
            caseleg=r'''3 Paddles, $30^{\circ}$ Pitch, Aspect 10'''          # legend for case
        else:
            caseleg=r'''3 Paddles, $30^{\circ}$ Pitch'''          # legend for case
  elif '-15deg-pitch' in padtype:
    angle=15.0
    rads=angle*np.pi/180.0
    nx =  np.cos(rads)
    ny = -np.sin(rads)
    nz =  0.0
    info=[\
    ['forces1f', 'Front 1', [ nx, ny, nz ]],
    ['forces1b', 'Back 1' , [ nx, ny, nz ]],
   #['forces2f', 'Front 2', [ nx, ny, nz ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ nx, ny, nz ]],
    ['forces3f', 'Front 3', [ nx, ny, nz ]],
    ['forces3b', 'Back 3' , [ nx, ny, nz ]],
   #['forces4f', 'Front 4', [ nx, ny, nz ]],
   #['forces4b', 'Back 4' , [ nx, ny, nz ]],
    ['forces5f', 'Front 5', [ nx, ny, nz ]],
    ['forces5b', 'Back 5' , [ nx, ny, nz ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    caseleg=r'''3 Paddles, $15^{\circ}$ Pitch'''          # legend for case
    if padtype == '_3flap-gap-15deg-pitch-2mFloor':
      caseleg=r'''3 Paddles, $15^{\circ}$ Pitch, near floor'''          # legend for case
  elif '-35deg-pitch' in padtype:
    angle=35.0
    rads=angle*np.pi/180.0
    nx =  np.cos(rads)
    ny = -np.sin(rads)
    nz =  0.0
    info=[\
    ['forces1f', 'Front 1', [ nx, ny, nz ]],
    ['forces1b', 'Back 1' , [ nx, ny, nz ]],
   #['forces2f', 'Front 2', [ nx, ny, nz ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ nx, ny, nz ]],
    ['forces3f', 'Front 3', [ nx, ny, nz ]],
    ['forces3b', 'Back 3' , [ nx, ny, nz ]],
   #['forces4f', 'Front 4', [ nx, ny, nz ]],
   #['forces4b', 'Back 4' , [ nx, ny, nz ]],
    ['forces5f', 'Front 5', [ nx, ny, nz ]],
    ['forces5b', 'Back 5' , [ nx, ny, nz ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00', '4.00' ]
    caseleg=r'''3 Paddles, $35^{\circ}$ Pitch'''          # legend for case
  elif '-40deg-pitch' in padtype:
    angle=40.0
    rads=angle*np.pi/180.0
    nx =  np.cos(rads)
    ny = -np.sin(rads)
    nz =  0.0
    info=[\
    ['forces1f', 'Front 1', [ nx, ny, nz ]],
    ['forces1b', 'Back 1' , [ nx, ny, nz ]],
   #['forces2f', 'Front 2', [ nx, ny, nz ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ nx, ny, nz ]],
    ['forces3f', 'Front 3', [ nx, ny, nz ]],
    ['forces3b', 'Back 3' , [ nx, ny, nz ]],
   #['forces4f', 'Front 4', [ nx, ny, nz ]],
   #['forces4b', 'Back 4' , [ nx, ny, nz ]],
    ['forces5f', 'Front 5', [ nx, ny, nz ]],
    ['forces5b', 'Back 5' , [ nx, ny, nz ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00', '4.00' ]
    caseleg=r'''3 Paddles, $40^{\circ}$ Pitch'''          # legend for case
  elif '-45deg-pitch' in padtype:
    angle=45.0
    rads=angle*np.pi/180.0
    nx =  np.cos(rads)
    ny = -np.sin(rads)
    nz =  0.0
    info=[\
    ['forces1f', 'Front 1', [ nx, ny, nz ]],
    ['forces1b', 'Back 1' , [ nx, ny, nz ]],
   #['forces2f', 'Front 2', [ nx, ny, nz ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ nx, ny, nz ]],
    ['forces3f', 'Front 3', [ nx, ny, nz ]],
    ['forces3b', 'Back 3' , [ nx, ny, nz ]],
   #['forces4f', 'Front 4', [ nx, ny, nz ]],
   #['forces4b', 'Back 4' , [ nx, ny, nz ]],
    ['forces5f', 'Front 5', [ nx, ny, nz ]],
    ['forces5b', 'Back 5' , [ nx, ny, nz ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    caseleg=r'''3 Paddles, $45^{\circ}$ Pitch'''          # legend for case
  elif '-60deg-pitch' in padtype:
    angle=60.0
    rads=angle*np.pi/180.0
    nx =  np.cos(rads)
    ny = -np.sin(rads)
    nz =  0.0
    info=[\
    ['forces1f', 'Front 1', [ nx, ny, nz ]],
    ['forces1b', 'Back 1' , [ nx, ny, nz ]],
   #['forces2f', 'Front 2', [ nx, ny, nz ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ nx, ny, nz ]],
    ['forces3f', 'Front 3', [ nx, ny, nz ]],
    ['forces3b', 'Back 3' , [ nx, ny, nz ]],
   #['forces4f', 'Front 4', [ nx, ny, nz ]],
   #['forces4b', 'Back 4' , [ nx, ny, nz ]],
    ['forces5f', 'Front 5', [ nx, ny, nz ]],
    ['forces5b', 'Back 5' , [ nx, ny, nz ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    caseleg=r'''3 Paddles, $60^{\circ}$ Pitch'''          # legend for case
  elif '-15deg-yaw' in padtype:
    angle=15.0
    rads=angle*np.pi/180.0
    nx =  np.cos(rads)
    ny =  0.0
    nz =  np.sin(rads)
    info=[\
    ['forces1f', 'Front 1', [ nx, ny, nz ]],
    ['forces1b', 'Back 1' , [ nx, ny, nz ]],
   #['forces2f', 'Front 2', [ nx, ny, nz ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ nx, ny, nz ]],
    ['forces3f', 'Front 3', [ nx, ny, nz ]],
    ['forces3b', 'Back 3' , [ nx, ny, nz ]],
   #['forces4f', 'Front 4', [ nx, ny, nz ]],
   #['forces4b', 'Back 4' , [ nx, ny, nz ]],
    ['forces5f', 'Front 5', [ nx, ny, nz ]],
    ['forces5b', 'Back 5' , [ nx, ny, nz ]],
    ]
    symscale=[1,1,1,1,1,1]
    vellist=[ '1.00', '2.00' ]
    caseleg=r'''3 Paddles, $15^{\circ}$ Yaw'''          # legend for case
    if '_0.1x' in padtype:
        iscale = 1
        caseleg=r'''3 paddles, Yaw $15^{\circ}$ $0.1\times$ Scale'''
        symscale=[100.0,100.0,100.0,100.0,100.0,100.0]
    elif '_10x' in padtype:
        iscale = 1
        caseleg=r'''3 paddles, Yaw $15^{\circ}$ $10\times$ Scale'''
        symscale=[0.01,0.01,0.01,0.01,0.01,0.01]

  elif '-30deg-yaw' in padtype:
    angle=30.0
    rads=angle*np.pi/180.0
    nx =  np.cos(rads)
    ny =  0.0
    nz =  np.sin(rads)
    info=[\
    ['forces1f', 'Front 1', [ nx, ny, nz ]],
    ['forces1b', 'Back 1' , [ nx, ny, nz ]],
   #['forces2f', 'Front 2', [ nx, ny, nz ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ nx, ny, nz ]],
    ['forces3f', 'Front 3', [ nx, ny, nz ]],
    ['forces3b', 'Back 3' , [ nx, ny, nz ]],
   #['forces4f', 'Front 4', [ nx, ny, nz ]],
   #['forces4b', 'Back 4' , [ nx, ny, nz ]],
    ['forces5f', 'Front 5', [ nx, ny, nz ]],
    ['forces5b', 'Back 5' , [ nx, ny, nz ]],
    ]
    symscale=[1,1,1,1,1,1]
    vellist=[ '1.00', '2.00' ]
    caseleg=r'''3 Paddles, $30^{\circ}$ Yaw'''          # legend for case
  elif '_tank-3flap' in padtype:
    info=[\
    ['forces1f', 'Front 1', [ 0.914,-0.406, 0.0]],
    ['forces1b', 'Back 1' , [ 0.914,-0.406, 0.0]],
    ['forces3f', 'Front 3', [ 1.0  , 0.0  , 0.0]],
    ['forces3b', 'Back 3' , [ 1.0  , 0.0  , 0.0]],
    ['forces5f', 'Front 5', [ 0.914, 0.406, 0.0]],
    ['forces5b', 'Back 5' , [ 0.914, 0.406, 0.0]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    caseleg=r'''3 Paddles, Trapezoidal'''          # legend for case
  elif '_tank' in padtype:
    ## third column is the paddle normal for forces
    info=[\
    ['forces1f', 'Front 1', [ 0.914,-0.406, 0.0]],
    ['forces1b', 'Back 1' , [ 0.914,-0.406, 0.0]],
    ['forces2f', 'Front 2', [ 0.914,-0.406, 0.0]],
    ['forces2b', 'Back 2' , [ 0.914,-0.406, 0.0]],
    ['forces3f', 'Front 3', [ 1.0  , 0.0  , 0.0]],
    ['forces3b', 'Back 3' , [ 1.0  , 0.0  , 0.0]],
    ['forces4f', 'Front 4', [ 0.914, 0.406, 0.0]],
    ['forces4b', 'Back 4' , [ 0.914, 0.406, 0.0]],
    ['forces5f', 'Front 5', [ 0.914, 0.406, 0.0]],
    ['forces5b', 'Back 5' , [ 0.914, 0.406, 0.0]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    caseleg=r'''5 Paddles, Trapezoidal'''          # legend for case
  elif '5flap' in padtype:
    info=[\
    ['forces1f', 'Front 1', [ 1.0  , 0.0  , 0.0 ]],
    ['forces1b', 'Back 1' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces2f', 'Front 2', [ 1.0  , 0.0  , 0.0 ]],  ## don't exist in 3 paddle cases
    ['forces2b', 'Back 2' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces3f', 'Front 3', [ 1.0  , 0.0  , 0.0 ]],
    ['forces3b', 'Back 3' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces4f', 'Front 4', [ 1.0  , 0.0  , 0.0 ]],
    ['forces4b', 'Back 4' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces5f', 'Front 5', [ 1.0  , 0.0  , 0.0 ]],
    ['forces5b', 'Back 5' , [ 1.0  , 0.0  , 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    if '-a10' in padtype:
        caseleg='5 Paddles, Aspect 10'          # legend for case
        vellist=[ '1.00', '2.00' ]
    else:
        caseleg='5 Paddles'          # legend for case
        vellist=['0.50', '1.00', '1.50', '1.75', '2.00', '2.50', '3.00']
  else: ## 3flap
    info=[\
    ['forces1f', 'Front 1', [ 1.0  , 0.0  , 0.0 ]],
    ['forces1b', 'Back 1' , [ 1.0  , 0.0  , 0.0 ]],
   #['forces2f', 'Front 2', [ 1.0  , 0.0  , 0.0 ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces3f', 'Front 3', [ 1.0  , 0.0  , 0.0 ]],
    ['forces3b', 'Back 3' , [ 1.0  , 0.0  , 0.0 ]],
   #['forces4f', 'Front 4', [ 1.0  , 0.0  , 0.0 ]],
   #['forces4b', 'Back 4' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces5f', 'Front 5', [ 1.0  , 0.0  , 0.0 ]],
    ['forces5b', 'Back 5' , [ 1.0  , 0.0  , 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    if '-pours' in padtype:
        caseleg='3 Paddles, Gap, Porous'          # legend for case
    elif '-a2' in padtype:
        caseleg='3 Paddles, Gap, Aspect 2.0'
    elif '-a5' in padtype:
        caseleg='3 Paddles, Gap, Aspect 5.0'
    elif '-a10' in padtype:
        caseleg='3 Paddles, Gap, Aspect 10.0'
    elif '-nozzles' in padtype:
        caseleg='3 Paddles, Gap, Nozzle'          # legend for case
    elif '-gap' in padtype:
        caseleg='3 Paddles, Gap'          # legend for case
    elif '-2xgap' in padtype:
        caseleg='3 Paddles, 2x Gap'          # legend for case
    elif '-a10' in padtype:
        caseleg='3 Paddles, Aspect 10'          # legend for case
    else:
        caseleg='3 Paddles'          # legend for case
        #vellist=['0.50', '1.00', '1.50', '2.00', '2.50', '3.00']

  casetex=r'''\def\casedir{U2.00'''+padtype+r'''}
\def\casename{'''+caseleg+r''', U = 2.0}
\addCase{\casename}{\casedir}

%% ADD CASES HERE'''
  texdata = texdata.replace(r'''%% ADD CASES HERE''', casetex)

  #paddle surface directories
  fdirlist=[val[0] for val in info]

  #plotting legends
  fleglist=[val[1] for val in info]

  #plotting legends
  normlist=[val[2] for val in info]

  force_data=[]  ## force as a function of velocity
  avgCd=0.0
  for vel in vellist:
    casename='U'+vel+padtype    #U0.50_5flaps

    forcetot=0.0
    ## read steady-state forces from each paddle
    for iset in range(len(fdirlist)):
      fdir=fdirlist[iset]
      fleg=fleglist[iset]
      Nrmx=normlist[iset][0]
      Nrmy=normlist[iset][1]
      Nrmz=normlist[iset][2]

      ## sort directories by time value (as opposed to alphabetical time 100 < 20)
      forcedir='/gpfs/ccchart/ECOSSE/RUNS/'+casename+'/postProcessing/'+fdir+'/'
      forcefiles=glob.glob(forcedir+'*/force.dat')

      if len(forcefiles) > 1:
        # get time values and make floats for sorting
        forcetimes=[float(file.replace(forcedir,'').replace('/force.dat','')) for file in forcefiles]

        # sort on time and throw away time array
        forcefiles=[file for dummy,file in sorted(zip(forcetimes,forcefiles))]

      # moments are separate now

      # read last force file (can be multiple if restarted)
      print(forcedir,forcefiles)
      ffile = forcefiles[-1]
      with open(ffile) as fin:
        # skip header
        for i in range(4):
            fin.readline()

        data = fin.readlines()

      # remove parentheses and split
      data1 = np.array([[float(val) for val in np.array(line.replace('(','').replace(')','').split())] for line in data])

      ## data form
      ## Time        forces(pressure viscous porous)   moments(pressure viscous porous)
      time = data1[:,0]

      # columns are:    total    pressure     viscous      porous (not used)
      Fx = data1[-1,1]*symscale[0]
      Fy = data1[-1,2]*symscale[1]
      Fz = data1[-1,3]*symscale[2]

      fnrm = Fx*Nrmx + Fy*Nrmy + Fz*Nrmz
      #fnrm = np.sqrt(Fx*Fx + Fy*Fy + Fz*Fz)  ## this is always positive, bad!!

      forcetot += fnrm

    ## end of paddle surface loop

    # store total paddle force at this velocity
    force_data.append(forcetot)

    Cd = forcetot/(0.5*paddleArea*rho*float(vel)**2)
    avgCd += Cd
  ## end of vel loop
  avgCd = avgCd/float(len(vellist))
  print('Average F/(0.5*A*rho*U^2) = {}'.format(avgCd))
  CdList.append(avgCd)

  ## plot force vs velocity for this paddle type
  xx = np.array([float(val) for val in vellist])

  linecolor = next(color)
  ## don't want iterator, want literally this color to use multiple times
  #import copy
  #c = copy.deepcopy(next(color))

  plt.plot(xx,force_data,'o',color=linecolor,label=caseleg)

  ## get Cd curve fit
  fit = np.polyfit(xx, force_data, 2)
  ## fit is F = ax^2 + bx + c
  a = fit[0]
  b = fit[1]
  c = fit[2] #should be near 0
  print('Curve fit: F = {}x^2 + {}x + {}'.format(a,b,c))
  print('Curve fit Cd: {}'.format(a/(0.5*paddleArea*rho)))

  xx = np.linspace(float(vellist[0]),float(vellist[-1]),100)
  plt.plot(xx,0.5*avgCd*rho*paddleArea*xx*xx,color=linecolor)
  #plt.plot(xx,0.5*avgCd*rho*paddleArea*xx*xx,label=r'$\frac{{{0:.2f}}}{{2}} \rho A u^2$'.format(avgCd))
## end of paddle type loop


## writeout Cd table
with open('Cd.tex','w') as fout:
  lineout=r'''%% Table automatically generated by force_summary.py script
\begin{tabular}{c c}
    Design Type & Force Coefficient
    \rule[-1.5ex]{0pt}{0pt}\
    \\
    \hline'''
  fout.write(lineout)

  print(padlist)
  print(texlist)
  print(CdList)
  for i in range(len(padlist)):
    lineout = r'''
    {:^10s} & {:6.4f} \\
        \hline'''.format(texlist[i][:],CdList[i])

    ## write table begin  \rule adds a buffer space below the title to fit the fraction
    #print(lineout)
    fout.write(lineout)

  lineout=r'''
\end{tabular}'''
  fout.write(lineout+"\n")

## plot lines
#plt.rcParams["figure.figsize"] = (8,4)
plt.title('Net Paddle-Normal Force vs Velocity')
plt.xlabel('Velocity (m/s)')

plt.ylabel('Force (N)')
if iscale == 1: 
    plt.ylabel('Scaled Force (N)')

#plt.xlim(0,3.5)
#plt.ylim(0,6000)
#plt.legend(loc='lower center')
#plt.legend(loc='upper left')
plt.legend(bbox_to_anchor=(1.05, 1), loc='upper left') ## place at x=1.05 from upper left
plt.tight_layout()
#plt.show()
plt.savefig('./force-summary.png')
plt.clf()

## write out tex file
with open('newtex.tex','w') as fout:
  fout.write(texdata)



