#!/usr/bin/env python3

import matplotlib.pyplot as plt
import numpy as np
import glob, os, sys
import itertools

#import matplotlib
#matplotlib.rcParams.update({'font.size': 16})
params={
          'text.latex.preamble' : [r'\usepackage{amsmath}'],
                'font.size':14,
                    }
plt.rcParams.update(params)
plt.figure(figsize=(10, 6))

padlist=[\
         '_3flap-gap-a2',\
         '_3flap-gap-a5',\
         '_3flap-gap-a10',\
         ]

texlist=[\
         r'''Aspect 2.0, $1.13875 \times 0.5695$''',\
         r'''Aspect 5.0, $1.8005 \times 0.3601$''',\
         r'''Aspect 10.0, $2.546 \times 0.2546$''',\
         ]
ncases=len(padlist)

#colormap=plt.cm.rainbow
colormap=plt.cm.tab10  ## depending how many cases there are
#colormap=plt.cm.tab20
#colormap=plt.cm.tab20b
#colormap=plt.cm.tab20c

color = iter(colormap(np.linspace(0, 1, colormap.N)))
color = itertools.cycle(color)

paddleArea = 0.975*0.665 ## width * height
## Area is constant for all aspect ration studies
## A2  is 1.13875* 0.5695
## A5  is 1.8005 * 0.3601
## A10 is 2.546  * 0.2546

rho=1000.0

## force data is 10 columns, onreally reall care about time and total_x
## Time            (total_x total_y total_z)   (pressure_x pressure_y pressure_z)  (viscous_x viscous_y viscous_z)
ncolumns=10

CdList=[]

for padtype in padlist:
  print ('Analyzing design '+padtype[1:])
  if '-a2' in padtype:
    info=[\
    ['forces1f', 'Front 1', [ 1.0  , 0.0  , 0.0 ]],
    ['forces1b', 'Back 1' , [ 1.0  , 0.0  , 0.0 ]],
   #['forces2f', 'Front 2', [ 1.0  , 0.0  , 0.0 ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces3f', 'Front 3', [ 1.0  , 0.0  , 0.0 ]],
    ['forces3b', 'Back 3' , [ 1.0  , 0.0  , 0.0 ]],
   #['forces4f', 'Front 4', [ 1.0  , 0.0  , 0.0 ]],
   #['forces4b', 'Back 4' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces5f', 'Front 5', [ 1.0  , 0.0  , 0.0 ]],
    ['forces5b', 'Back 5' , [ 1.0  , 0.0  , 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    caseleg='3 Flaps, Aspect 2'          # legend for case
  elif '-a5' in padtype:
    info=[\
    ['forces1f', 'Front 1', [ 1.0  , 0.0  , 0.0 ]],
    ['forces1b', 'Back 1' , [ 1.0  , 0.0  , 0.0 ]],
   #['forces2f', 'Front 2', [ 1.0  , 0.0  , 0.0 ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces3f', 'Front 3', [ 1.0  , 0.0  , 0.0 ]],
    ['forces3b', 'Back 3' , [ 1.0  , 0.0  , 0.0 ]],
   #['forces4f', 'Front 4', [ 1.0  , 0.0  , 0.0 ]],
   #['forces4b', 'Back 4' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces5f', 'Front 5', [ 1.0  , 0.0  , 0.0 ]],
    ['forces5b', 'Back 5' , [ 1.0  , 0.0  , 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    caseleg='3 Flaps, Aspect 5'          # legend for case
  elif '-a10' in padtype:
    info=[\
    ['forces1f', 'Front 1', [ 1.0  , 0.0  , 0.0 ]],
    ['forces1b', 'Back 1' , [ 1.0  , 0.0  , 0.0 ]],
   #['forces2f', 'Front 2', [ 1.0  , 0.0  , 0.0 ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces3f', 'Front 3', [ 1.0  , 0.0  , 0.0 ]],
    ['forces3b', 'Back 3' , [ 1.0  , 0.0  , 0.0 ]],
   #['forces4f', 'Front 4', [ 1.0  , 0.0  , 0.0 ]],
   #['forces4b', 'Back 4' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces5f', 'Front 5', [ 1.0  , 0.0  , 0.0 ]],
    ['forces5b', 'Back 5' , [ 1.0  , 0.0  , 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    caseleg='3 Flaps, Aspect 10'          # legend for case

  #paddle surface directories
  fdirlist=[val[0] for val in info]

  #plotting legends
  fleglist=[val[1] for val in info]

  #plotting legends
  normlist=[val[2] for val in info]

  force_data=[]  ## force as a function of velocity
  avgCd=0.0
  for vel in vellist:
    casename='U'+vel+padtype    #U0.50_5flaps

    forcetot=0.0
    ## read steady-state forces from each paddle
    for iset in range(len(fdirlist)):
      fdir=fdirlist[iset]
      fleg=fleglist[iset]
      Nrmx=normlist[iset][0]
      Nrmy=normlist[iset][1]
      Nrmz=normlist[iset][2]

      ## sort directories by time value (as opposed to alphabetical time 100 < 20)
      forcedir=casename+'/postProcessing/'+fdir+'/'
      forcefiles=glob.glob(forcedir+'*/force.dat')

      if len(forcefiles) > 1:
        # get time values and make floats for sorting
        forcetimes=[float(file.replace(forcedir,'').replace('/force.dat','')) for file in forcefiles]

        # sort on time and throw away time array
        forcefiles=[file for dummy,file in sorted(zip(forcetimes,forcefiles))]

      # moments are separate now

      # read last force file (can be multiple if restarted)
      ffile = forcefiles[-1]
      with open(ffile) as fin:
        # skip header
        for i in range(4):
            fin.readline()

        data = fin.readlines()

      # remove parentheses and split
      data1 = np.array([[float(val) for val in np.array(line.replace('(','').replace(')','').split())] for line in data])

      ## data form
      ## Time        forces(pressure viscous porous)   moments(pressure viscous porous)
      time = data1[:,0]

      # columns are:    total    pressure     viscous      porous (not used)
      Fx = data1[:,1]*symscale[0]
      Fy = data1[:,2]*symscale[1]
      Fz = data1[:,3]*symscale[2]
      fnrm = Fx*Nrmx + Fy*Nrmy + Fz*Nrmz

      #forcetot += Fx[-1]
      forcetot += fnrm[-1]

    ## end of paddle surface loop

    # store total paddle force at this velocity
    force_data.append(forcetot)

    Cd = forcetot/(0.5*paddleArea*rho*float(vel)**2)
    avgCd += Cd
  ## end of vel loop
  avgCd = avgCd/float(len(vellist))
  print('Average F/(0.5*A*rho*U^2) = {}'.format(avgCd))
  CdList.append(avgCd)

  ## plot force vs velocity for this paddle type
  xx = np.array([float(val) for val in vellist])

  linecolor = next(color)
  ## don't want iterator, want literally this color to use multiple times
  #import copy
  #c = copy.deepcopy(next(color))

  plt.plot(xx,force_data,'o',color=linecolor,label=caseleg)

  ## get Cd curve fit
  fit = np.polyfit(xx, force_data, 2)
  ## fit is F = ax^2 + bx + c
  a = fit[0]
  b = fit[1]
  c = fit[2] #should be near 0
  print('Curve fit: F = {}x^2 + {}x + {}'.format(a,b,c))
  print('Curve fit Cd: {}'.format(a/(0.5*paddleArea*rho)))

  xx = np.linspace(float(vellist[0]),float(vellist[-1]),100)
  plt.plot(xx,0.5*avgCd*rho*paddleArea*xx*xx,color=linecolor)
  #plt.plot(xx,0.5*avgCd*rho*paddleArea*xx*xx,label=r'$\frac{{{0:.2f}}}{{2}} \rho A u^2$'.format(avgCd))
## end of paddle type loop


## writeout Cd table
with open('Cd-aspect.tex','w') as fout:
  lineout=r'''%% Table automatically generated by force_summary.py script
\begin{tabular}{c c}
    Design Type & Force Coefficient
    \rule[-1.5ex]{0pt}{0pt}\
    \\
    \hline'''
  fout.write(lineout)

  for i in range(len(padlist)):
    lineout = r'''
    {:^10s} & {:6.4f} \\
        \hline'''.format(texlist[i][:],CdList[i])

    ## write table begin  \rule adds a buffer space below the title to fit the fraction
    #print(lineout)
    fout.write(lineout)

  lineout=r'''
\end{tabular}'''
  fout.write(lineout+"\n")

## plot lines
#plt.rcParams["figure.figsize"] = (8,4)
plt.title('Net Paddle-Normal Force vs Velocity')
plt.xlabel('Velocity (m/s)')
plt.ylabel('Force (N)')
#plt.xlim(0,3.5)
#plt.ylim(0,6000)
#plt.legend(loc='lower center')
#plt.legend(loc='upper left')
plt.legend(bbox_to_anchor=(1.05, 1), loc='upper left') ## place at x=1.05 from upper left
plt.tight_layout()
#plt.show()
plt.savefig('./images/force-summary-aspect.png')
plt.clf()


