#!/usr/bin/env python3

import matplotlib.pyplot as plt
import numpy as np
import glob, os, sys
import itertools

#import matplotlib
#matplotlib.rcParams.update({'font.size': 16})
params={
          'text.latex.preamble' : [r'\usepackage{amsmath}'],
                'font.size':14,
                    }
plt.rcParams.update(params)
plt.figure(figsize=(10, 6))

padlist=[\
         '_3flap-gap',\
         '_3flap-gap-a10',\
         '_5flap-gap-a10',\
         '_3flap-gap-a10-30deg-pitch',\
         '_5flap-gap-a10-30deg-pitch',\
         '_3flap-gap-15deg-pitch',\
         '_3flap-gap-30deg-pitch',\
         '_3flap-gap-35deg-pitch',\
         '_3flap-gap-40deg-pitch',\
         '_3flap-gap-45deg-pitch',\
         '_3flap-gap-60deg-pitch',\
         ]

texlist=[\
         r'''3 paddles''',\
         r'''3 paddles, Aspect 10.0''',\
         r'''5 paddles, Aspect 10.0''',\
         r'''3 paddles, Aspect 10.0, Pitch $30^{\circ}$''',\
         r'''5 paddles, Aspect 10.0, Pitch $30^{\circ}$''',\
         r'''3 paddles, Pitch $15^{\circ}$''',\
         r'''3 paddles, Pitch $30^{\circ}$''',\
         r'''3 paddles, Pitch $35^{\circ}$''',\
         r'''3 paddles, Pitch $40^{\circ}$''',\
         r'''3 paddles, Pitch $45^{\circ}$''',\
         r'''3 paddles, Pitch $60^{\circ}$''',\
         ]
ncases=len(padlist)

#colormap=plt.cm.rainbow
colormap=plt.cm.tab10  ## depending how many cases there are
#colormap=plt.cm.tab20
#colormap=plt.cm.tab20b
#colormap=plt.cm.tab20c

color = iter(colormap(np.linspace(0, 1, colormap.N)))
color = itertools.cycle(color)

paddleArea = 0.975*0.665 ## width * height
## Area is constant for all aspect ration studies
## A2  is 1.13875* 0.5695
## A5  is 1.8005 * 0.3601
## A10 is 2.546  * 0.2546

rho=1000.0

## force data is 10 columns, onreally reall care about time and total_x
## Time            (total_x total_y total_z)   (pressure_x pressure_y pressure_z)  (viscous_x viscous_y viscous_z)
ncolumns=10

CdList=[]

for padtype in padlist:
  print ('Analyzing design '+padtype[1:])
  if '-30deg-' in padtype:
    if '5flap' in padtype:
        info=[\
        ['forces1f', 'Front 1', [ 0.8660254, -0.5, 0.0 ]],
        ['forces1b', 'Back 1' , [ 0.8660254, -0.5, 0.0 ]],
        ['forces2f', 'Front 2', [ 0.8660254, -0.5, 0.0 ]],  ## don't exist in 3 paddle cases
        ['forces2b', 'Back 2' , [ 0.8660254, -0.5, 0.0 ]],
        ['forces3f', 'Front 3', [ 0.8660254, -0.5, 0.0 ]],
        ['forces3b', 'Back 3' , [ 0.8660254, -0.5, 0.0 ]],
        ['forces4f', 'Front 4', [ 0.8660254, -0.5, 0.0 ]],
        ['forces4b', 'Back 4' , [ 0.8660254, -0.5, 0.0 ]],
        ['forces5f', 'Front 5', [ 0.8660254, -0.5, 0.0 ]],
        ['forces5b', 'Back 5' , [ 0.8660254, -0.5, 0.0 ]],
        ]
        symscale=[2,2,0,0,0,2]
        vellist=[ '1.00', '2.00' ]
        if '-a10' in padtype:
            caseleg=r'''5 Flaps, $30^{\circ}$ Aspect 10'''          # legend for case
        else:
            caseleg=r'''5 Flaps, $30^{\circ}$'''          # legend for case
    else:
        info=[\
        ['forces1f', 'Front 1', [ 0.8660254, -0.5, 0.0 ]],
        ['forces1b', 'Back 1' , [ 0.8660254, -0.5, 0.0 ]],
       #['forces2f', 'Front 2', [ 0.8660254, -0.5, 0.0 ]],  ## don't exist in 3 paddle cases
       #['forces2b', 'Back 2' , [ 0.8660254, -0.5, 0.0 ]],
        ['forces3f', 'Front 3', [ 0.8660254, -0.5, 0.0 ]],
        ['forces3b', 'Back 3' , [ 0.8660254, -0.5, 0.0 ]],
       #['forces4f', 'Front 4', [ 0.8660254, -0.5, 0.0 ]],
       #['forces4b', 'Back 4' , [ 0.8660254, -0.5, 0.0 ]],
        ['forces5f', 'Front 5', [ 0.8660254, -0.5, 0.0 ]],
        ['forces5b', 'Back 5' , [ 0.8660254, -0.5, 0.0 ]],
        ]
        symscale=[2,2,0,0,0,2]
        vellist=[ '1.00', '2.00' ]
        if '-a10' in padtype:
            caseleg=r'''3 Flaps, $30^{\circ}$ Aspect 10'''          # legend for case
        else:
            caseleg=r'''3 Flaps, $30^{\circ}$'''          # legend for case
  elif '-15deg-' in padtype:
    info=[\
    ['forces1f', 'Front 1', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces1b', 'Back 1' , [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces2f', 'Front 2', [ 0.70710678, -0.70710678, 0.0 ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces3f', 'Front 3', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces3b', 'Back 3' , [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces4f', 'Front 4', [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces4b', 'Back 4' , [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces5f', 'Front 5', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces5b', 'Back 5' , [ 0.70710678, -0.70710678, 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    caseleg=r'''3 Flaps, $15^{\circ}$'''          # legend for case
  elif '-35deg-' in padtype:
    info=[\
    ['forces1f', 'Front 1', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces1b', 'Back 1' , [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces2f', 'Front 2', [ 0.70710678, -0.70710678, 0.0 ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces3f', 'Front 3', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces3b', 'Back 3' , [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces4f', 'Front 4', [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces4b', 'Back 4' , [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces5f', 'Front 5', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces5b', 'Back 5' , [ 0.70710678, -0.70710678, 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00', '4.00' ]
    caseleg=r'''3 Flaps, $35^{\circ}$'''          # legend for case
  elif '-40deg-' in padtype:
    info=[\
    ['forces1f', 'Front 1', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces1b', 'Back 1' , [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces2f', 'Front 2', [ 0.70710678, -0.70710678, 0.0 ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces3f', 'Front 3', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces3b', 'Back 3' , [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces4f', 'Front 4', [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces4b', 'Back 4' , [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces5f', 'Front 5', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces5b', 'Back 5' , [ 0.70710678, -0.70710678, 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00', '4.00' ]
    caseleg=r'''3 Flaps, $40^{\circ}$'''          # legend for case
  elif '-45deg-' in padtype:
    info=[\
    ['forces1f', 'Front 1', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces1b', 'Back 1' , [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces2f', 'Front 2', [ 0.70710678, -0.70710678, 0.0 ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces3f', 'Front 3', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces3b', 'Back 3' , [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces4f', 'Front 4', [ 0.70710678, -0.70710678, 0.0 ]],
   #['forces4b', 'Back 4' , [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces5f', 'Front 5', [ 0.70710678, -0.70710678, 0.0 ]],
    ['forces5b', 'Back 5' , [ 0.70710678, -0.70710678, 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    caseleg=r'''3 Flaps, $45^{\circ}$'''          # legend for case
  elif '-60deg-' in padtype:
    info=[\
    ['forces1f', 'Front 1', [ 0.5,  -0.8660254, 0.0 ]],
    ['forces1b', 'Back 1' , [ 0.5,  -0.8660254, 0.0 ]],
   #['forces2f', 'Front 2', [ 0.5,  -0.8660254, 0.0 ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ 0.5,  -0.8660254, 0.0 ]],
    ['forces3f', 'Front 3', [ 0.5,  -0.8660254, 0.0 ]],
    ['forces3b', 'Back 3' , [ 0.5,  -0.8660254, 0.0 ]],
   #['forces4f', 'Front 4', [ 0.5,  -0.8660254, 0.0 ]],
   #['forces4b', 'Back 4' , [ 0.5,  -0.8660254, 0.0 ]],
    ['forces5f', 'Front 5', [ 0.5,  -0.8660254, 0.0 ]],
    ['forces5b', 'Back 5' , [ 0.5,  -0.8660254, 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    caseleg=r'''3 Flaps, $60^{\circ}$'''          # legend for case
  elif '5flap' in padtype:
    info=[\
    ['forces1f', 'Front 1', [ 1.0  , 0.0  , 0.0 ]],
    ['forces1b', 'Back 1' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces2f', 'Front 2', [ 1.0  , 0.0  , 0.0 ]],  ## don't exist in 3 paddle cases
    ['forces2b', 'Back 2' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces3f', 'Front 3', [ 1.0  , 0.0  , 0.0 ]],
    ['forces3b', 'Back 3' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces4f', 'Front 4', [ 1.0  , 0.0  , 0.0 ]],
    ['forces4b', 'Back 4' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces5f', 'Front 5', [ 1.0  , 0.0  , 0.0 ]],
    ['forces5b', 'Back 5' , [ 1.0  , 0.0  , 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    if '-a10' in padtype:
        caseleg='5 Flaps, Aspect 10'          # legend for case
    else:
        caseleg='5 Flaps'          # legend for case
  else: ## 3flap
    info=[\
    ['forces1f', 'Front 1', [ 1.0  , 0.0  , 0.0 ]],
    ['forces1b', 'Back 1' , [ 1.0  , 0.0  , 0.0 ]],
   #['forces2f', 'Front 2', [ 1.0  , 0.0  , 0.0 ]],  ## don't exist in 3 paddle cases
   #['forces2b', 'Back 2' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces3f', 'Front 3', [ 1.0  , 0.0  , 0.0 ]],
    ['forces3b', 'Back 3' , [ 1.0  , 0.0  , 0.0 ]],
   #['forces4f', 'Front 4', [ 1.0  , 0.0  , 0.0 ]],
   #['forces4b', 'Back 4' , [ 1.0  , 0.0  , 0.0 ]],
    ['forces5f', 'Front 5', [ 1.0  , 0.0  , 0.0 ]],
    ['forces5b', 'Back 5' , [ 1.0  , 0.0  , 0.0 ]],
    ]
    symscale=[2,2,0,0,0,2]
    vellist=[ '1.00', '2.00' ]
    if '-a10' in padtype:
        caseleg='3 Flaps, Aspect 10'          # legend for case
    else:
        caseleg='3 Flaps'          # legend for case

  #paddle surface directories
  fdirlist=[val[0] for val in info]

  #plotting legends
  fleglist=[val[1] for val in info]

  #plotting legends
  normlist=[val[2] for val in info]

  force_data=[]  ## force as a function of velocity
  avgCd=0.0
  for vel in vellist:
    casename='U'+vel+padtype    #U0.50_5flaps

    forcetot=0.0
    ## read steady-state forces from each paddle
    for iset in range(len(fdirlist)):
      fdir=fdirlist[iset]
      fleg=fleglist[iset]
      Nrmx=normlist[iset][0]
      Nrmy=normlist[iset][1]
      Nrmz=normlist[iset][2]

      ## sort directories by time value (as opposed to alphabetical time 100 < 20)
      forcedir=casename+'/postProcessing/'+fdir+'/'
      forcefiles=glob.glob(forcedir+'*/force.dat')

      if len(forcefiles) > 1:
        # get time values and make floats for sorting
        forcetimes=[float(file.replace(forcedir,'').replace('/force.dat','')) for file in forcefiles]

        # sort on time and throw away time array
        forcefiles=[file for dummy,file in sorted(zip(forcetimes,forcefiles))]

      # moments are separate now

      # read last force file (can be multiple if restarted)
      ffile = forcefiles[-1]
      with open(ffile) as fin:
        # skip header
        for i in range(4):
            fin.readline()

        data = fin.readlines()

      # remove parentheses and split
      data1 = np.array([[float(val) for val in np.array(line.replace('(','').replace(')','').split())] for line in data])

      ## data form
      ## Time        forces(pressure viscous porous)   moments(pressure viscous porous)
      time = data1[:,0]

      # columns are:    total    pressure     viscous      porous (not used)
      Fx = data1[-1,1]*symscale[0]
      Fy = data1[-1,2]*symscale[1]
      Fz = data1[-1,3]*symscale[2]

      fnrm = Fx*Nrmx + Fy*Nrmy + Fz*Nrmz
      #fnrm = np.sqrt(Fx*Fx + Fy*Fy + Fz*Fz)  ## this is always positive, bad!!

      forcetot += fnrm

    ## end of paddle surface loop

    # store total paddle force at this velocity
    force_data.append(forcetot)

    Cd = forcetot/(0.5*paddleArea*rho*float(vel)**2)
    avgCd += Cd
  ## end of vel loop
  avgCd = avgCd/float(len(vellist))
  print('Average F/(0.5*A*rho*U^2) = {}'.format(avgCd))
  CdList.append(avgCd)

  ## plot force vs velocity for this paddle type
  xx = np.array([float(val) for val in vellist])

  linecolor = next(color)
  ## don't want iterator, want literally this color to use multiple times
  #import copy
  #c = copy.deepcopy(next(color))

  plt.plot(xx,force_data,'o',color=linecolor,label=caseleg)

  ## get Cd curve fit
  fit = np.polyfit(xx, force_data, 2)
  ## fit is F = ax^2 + bx + c
  a = fit[0]
  b = fit[1]
  c = fit[2] #should be near 0
  print('Curve fit: F = {}x^2 + {}x + {}'.format(a,b,c))
  print('Curve fit Cd: {}'.format(a/(0.5*paddleArea*rho)))

  xx = np.linspace(float(vellist[0]),float(vellist[-1]),100)
  plt.plot(xx,0.5*avgCd*rho*paddleArea*xx*xx,color=linecolor)
  #plt.plot(xx,0.5*avgCd*rho*paddleArea*xx*xx,label=r'$\frac{{{0:.2f}}}{{2}} \rho A u^2$'.format(avgCd))
## end of paddle type loop


## writeout Cd table
with open('Cd-pitch.tex','w') as fout:
  lineout=r'''%% Table automatically generated by force_summary.py script
\begin{tabular}{c c}
    Design Type & Force Coefficient
    \rule[-1.5ex]{0pt}{0pt}\
    \\
    \hline'''
  fout.write(lineout)

  for i in range(len(padlist)):
    lineout = r'''
    {:^10s} & {:6.4f} \\
        \hline'''.format(texlist[i][:],CdList[i])

    ## write table begin  \rule adds a buffer space below the title to fit the fraction
    #print(lineout)
    fout.write(lineout)

  lineout=r'''
\end{tabular}'''
  fout.write(lineout+"\n")

## plot lines
#plt.rcParams["figure.figsize"] = (8,4)
plt.title('Net Paddle-Normal Force vs Velocity')
plt.xlabel('Velocity (m/s)')
plt.ylabel('Force (N)')
#plt.xlim(0,3.5)
#plt.ylim(0,6000)
#plt.legend(loc='lower center')
#plt.legend(loc='upper left')
plt.legend(bbox_to_anchor=(1.05, 1), loc='upper left') ## place at x=1.05 from upper left
plt.tight_layout()
#plt.show()
plt.savefig('./images/force-summary-pitch.png')
plt.clf()


