#!/usr/bin/env python3

import matplotlib.pyplot as plt
import numpy as np
import glob, os, sys


cwd=os.getcwd()
casename=os.path.basename(cwd)

print (casename)

symscale=[2,2,0,0,0,2]

if '_tank-3flap' in casename:
  info=[\
  ['forces1f', 'Front 1', [ 0.914,-0.406, 0.0]],
  ['forces1b', 'Back 1' , [ 0.914,-0.406, 0.0]],
  ['forces3f', 'Front 3', [ 1.0  , 0.0  , 0.0]],
  ['forces3b', 'Back 3' , [ 1.0  , 0.0  , 0.0]],
  ['forces5f', 'Front 5', [ 0.914, 0.406, 0.0]],
  ['forces5b', 'Back 5' , [ 0.914, 0.406, 0.0]],
  ]
elif '_tank' in casename:
  ## third column is the paddle normal for forces
  info=[\
  ['forces1f', 'Front 1', [ 0.914,-0.406, 0.0]],
  ['forces1b', 'Back 1' , [ 0.914,-0.406, 0.0]],
  ['forces2f', 'Front 2', [ 0.914,-0.406, 0.0]],
  ['forces2b', 'Back 2' , [ 0.914,-0.406, 0.0]],
  ['forces3f', 'Front 3', [ 1.0  , 0.0  , 0.0]],
  ['forces3b', 'Back 3' , [ 1.0  , 0.0  , 0.0]],
  ['forces4f', 'Front 4', [ 0.914, 0.406, 0.0]],
  ['forces4b', 'Back 4' , [ 0.914, 0.406, 0.0]],
  ['forces5f', 'Front 5', [ 0.914, 0.406, 0.0]],
  ['forces5b', 'Back 5' , [ 0.914, 0.406, 0.0]],
  ]
elif '_3flap-gap-15deg-pitch' in casename:
  info=[\
  ['forces1f', 'Front 1', [ 0.96592582, -0.25881904,  0.0 ]],
  ['forces1b', 'Back 1' , [ 0.96592582, -0.25881904,  0.0 ]],
  ['forces3f', 'Front 3', [ 0.96592582, -0.25881904,  0.0 ]],
  ['forces3b', 'Back 3' , [ 0.96592582, -0.25881904,  0.0 ]],
  ['forces5f', 'Front 5', [ 0.96592582, -0.25881904,  0.0 ]],
  ['forces5b', 'Back 5' , [ 0.96592582, -0.25881904,  0.0 ]],
  ]
elif '_3flap-gap-30deg-pitch' in casename:
  info=[\
  ['forces1f', 'Front 1', [ 0.8660254, -0.5,  0.0 ]],
  ['forces1b', 'Back 1' , [ 0.8660254, -0.5,  0.0 ]],
  ['forces3f', 'Front 3', [ 0.8660254, -0.5,  0.0 ]],
  ['forces3b', 'Back 3' , [ 0.8660254, -0.5,  0.0 ]],
  ['forces5f', 'Front 5', [ 0.8660254, -0.5,  0.0 ]],
  ['forces5b', 'Back 5' , [ 0.8660254, -0.5,  0.0 ]],
  ]
elif '_3flap-gap-a10-30deg-pitch' in casename:
  info=[\
  ['forces1f', 'Front 1', [ 0.8660254, -0.5,  0.0 ]],
  ['forces1b', 'Back 1' , [ 0.8660254, -0.5,  0.0 ]],
  ['forces3f', 'Front 3', [ 0.8660254, -0.5,  0.0 ]],
  ['forces3b', 'Back 3' , [ 0.8660254, -0.5,  0.0 ]],
  ['forces5f', 'Front 5', [ 0.8660254, -0.5,  0.0 ]],
  ['forces5b', 'Back 5' , [ 0.8660254, -0.5,  0.0 ]],
  ]
elif '_3flap-gap-45deg-pitch' in casename:
  info=[\
  ['forces1f', 'Front 1', [ 0.70710678, -0.70710678,  0.0 ]],
  ['forces1b', 'Back 1' , [ 0.70710678, -0.70710678,  0.0 ]],
  ['forces3f', 'Front 3', [ 0.70710678, -0.70710678,  0.0 ]],
  ['forces3b', 'Back 3' , [ 0.70710678, -0.70710678,  0.0 ]],
  ['forces5f', 'Front 5', [ 0.70710678, -0.70710678,  0.0 ]],
  ['forces5b', 'Back 5' , [ 0.70710678, -0.70710678,  0.0 ]],
  ]
elif '_3flap-gap-60deg-pitch' in casename:
  info=[\
  ['forces1f', 'Front 1', [ 0.5,  -0.8660254, 0.0 ]],
  ['forces1b', 'Back 1' , [ 0.5,  -0.8660254, 0.0 ]],
  ['forces3f', 'Front 3', [ 0.5,  -0.8660254, 0.0 ]],
  ['forces3b', 'Back 3' , [ 0.5,  -0.8660254, 0.0 ]],
  ['forces5f', 'Front 5', [ 0.5,  -0.8660254, 0.0 ]],
  ['forces5b', 'Back 5' , [ 0.5,  -0.8660254, 0.0 ]],
  ]
elif '_5flap-gap-a10-30deg-pitch' in casename:
  info=[\
  ['forces1f', 'Front 1', [ 0.8660254, -0.5,  0.0 ]],
  ['forces1b', 'Back 1' , [ 0.8660254, -0.5,  0.0 ]],
  ['forces2f', 'Front 2', [ 0.8660254, -0.5,  0.0 ]],
  ['forces2b', 'Back 2' , [ 0.8660254, -0.5,  0.0 ]],
  ['forces3f', 'Front 3', [ 0.8660254, -0.5,  0.0 ]],
  ['forces3b', 'Back 3' , [ 0.8660254, -0.5,  0.0 ]],
  ['forces4f', 'Front 4', [ 0.8660254, -0.5,  0.0 ]],
  ['forces4b', 'Back 4' , [ 0.8660254, -0.5,  0.0 ]],
  ['forces5f', 'Front 5', [ 0.8660254, -0.5,  0.0 ]],
  ['forces5b', 'Back 5' , [ 0.8660254, -0.5,  0.0 ]],
  ]
elif '_3flap-gap-15deg-yaw' in casename:
  symscale=[1,1,1,1,1,1]
  info=[\
  ['forces1f', 'Front 1', [ 0.96592582  , 0.0,  0.25881904 ]],
  ['forces1b', 'Back 1' , [ 0.96592582  , 0.0,  0.25881904 ]],
  ['forces3f', 'Front 3', [ 0.96592582  , 0.0,  0.25881904 ]],
  ['forces3b', 'Back 3' , [ 0.96592582  , 0.0,  0.25881904 ]],
  ['forces5f', 'Front 5', [ 0.96592582  , 0.0,  0.25881904 ]],
  ['forces5b', 'Back 5' , [ 0.96592582  , 0.0,  0.25881904 ]],
  ]
elif '_3flap-gap-30deg-yaw' in casename:
  symscale=[1,1,1,1,1,1]
  info=[\
  ['forces1f', 'Front 1', [ 0.8660254  , 0.0,  0.5 ]],
  ['forces1b', 'Back 1' , [ 0.8660254  , 0.0,  0.5 ]],
  ['forces3f', 'Front 3', [ 0.8660254  , 0.0,  0.5 ]],
  ['forces3b', 'Back 3' , [ 0.8660254  , 0.0,  0.5 ]],
  ['forces5f', 'Front 5', [ 0.8660254  , 0.0,  0.5 ]],
  ['forces5b', 'Back 5' , [ 0.8660254  , 0.0,  0.5 ]],
  ]
## regular flat surface
elif '_3flap' in casename:
  info=[\
  ['forces1f', 'Front 1', [ 1.0  , 0.0 , 0.0  ]],
  ['forces1b', 'Back 1' , [ 1.0  , 0.0 , 0.0  ]],
 #['forces2f', 'Front 2', [ 1.0  , 0.0 , 0.0  ]],  ## don't exist in 3 paddle cases
 #['forces2b', 'Back 2' , [ 1.0  , 0.0 , 0.0  ]],
  ['forces3f', 'Front 3', [ 1.0  , 0.0 , 0.0  ]],
  ['forces3b', 'Back 3' , [ 1.0  , 0.0 , 0.0  ]],
 #['forces4f', 'Front 4', [ 1.0  , 0.0 , 0.0  ]],
 #['forces4b', 'Back 4' , [ 1.0  , 0.0 , 0.0  ]],
  ['forces5f', 'Front 5', [ 1.0  , 0.0 , 0.0  ]],
  ['forces5b', 'Back 5' , [ 1.0  , 0.0 , 0.0  ]],
  ]
elif '_5flap' in casename:
  info=[\
  ['forces1f', 'Front 1', [ 1.0  , 0.0 , 0.0  ]],
  ['forces1b', 'Back 1' , [ 1.0  , 0.0 , 0.0  ]],
  ['forces2f', 'Front 2', [ 1.0  , 0.0 , 0.0  ]],
  ['forces2b', 'Back 2' , [ 1.0  , 0.0 , 0.0  ]],
  ['forces3f', 'Front 3', [ 1.0  , 0.0 , 0.0  ]],
  ['forces3b', 'Back 3' , [ 1.0  , 0.0 , 0.0  ]],
  ['forces4f', 'Front 4', [ 1.0  , 0.0 , 0.0  ]],
  ['forces4b', 'Back 4' , [ 1.0  , 0.0 , 0.0  ]],
  ['forces5f', 'Front 5', [ 1.0  , 0.0 , 0.0  ]],
  ['forces5b', 'Back 5' , [ 1.0  , 0.0 , 0.0  ]],
  ]
elif '_1flap' in casename and '-mirror' in casename:
  info=[\
  ['forces3f', 'Front 3', [ 1.0  , 0.0 , 0.0  ]],
  ['forces3b', 'Back 3' , [ 1.0  , 0.0 , 0.0  ]],
  ['forces4f', 'Front 3', [ 1.0  , 0.0 , 0.0  ]],
  ['forces4b', 'Back 3' , [ 1.0  , 0.0 , 0.0  ]],
  ]
elif '_1flap' in casename:
  info=[\
  ['forces3f', 'Front 3', [ 1.0  , 0.0 , 0.0  ]],
  ['forces3b', 'Back 3' , [ 1.0  , 0.0 , 0.0  ]],
  ]
else:
  print ('No post processing parameters for case: '+casename+'.')
  sys.exit(1)

nskip=15  ## wash out initial data

## for half z-symmetry, scal x-force, y-force and z-moment by 2


fcolumns=10

#piece directory
fdirlist=[val[0] for val in info]

#plotting legends
fleglist=[val[1] for val in info]

#face normals
normlist=[val[2] for val in info]

## steady-state forces
force_data=[]

## loop flaps
for iset in range(len(fdirlist)):
  fdir=fdirlist[iset]
  fleg=fleglist[iset]
  Nrmx=normlist[iset][0]
  Nrmy=normlist[iset][1]
  Nrmz=normlist[iset][2]

  ## sort directories by time value (as opposed to alphabetical time 100 < 20)
  forcedir='postProcessing/'+fdir+'/'
  forcefiles=glob.glob(forcedir+'*/force.dat')

  if len(forcefiles) > 1:
    # get time values and make floats for sorting
    forcetimes=[float(file.replace(forcedir,'').replace('/force.dat','')) for file in forcefiles]

    # sort on time and throw away time array
    forcefiles=[file for dummy,file in sorted(zip(forcetimes,forcefiles))]


  # get the data
  data=np.empty((0,fcolumns))

  ## loop forcefile (usually only one)
  for ffile in forcefiles:
    with open(ffile) as fin:
      # skip header
      for i in range(4):
          fin.readline()

      data1 = fin.readlines()

      # remove parentheses, split, and make float array
      data1 = np.array([[float(val) for val in line.replace('(','').replace(')','').split()] for line in data1])
      t0 = data1[0,0]  ## start time of new data

      # remove lines from data that are greater than time0 in data1
      nrec=len(data)  ## size of previous data
      icrop=-1
      for i in range(nrec-1,0,-1):  ## loop from end of previous data
          t = data[i,0]   ## if old data goes past start of new data, crop it
          if t < t0:       ## this line is before start of new data -> OK
              break
          else:
              icrop=i      ## this line is after new data, crop it
      ## append this onto (cropped) data
      data=np.vstack((data[:icrop,:],data1))

  # columns are:   Time        forces(pressure viscous porous) moments(pressure viscous porous)
  time = data[:,0]
  Fx = data[:,1]*symscale[0]
  Fy = data[:,2]*symscale[1]
  Fz = data[:,3]*symscale[2]

  #plt.plot(time[nskip:],Fx[nskip:],label=fleg)
  #force_data.append(Fx[-1])

  fnrm = Fx*Nrmx + Fy*Nrmy + Fz*Nrmz
  plt.plot(time[nskip:],fnrm[nskip:],label=fleg)
  force_data.append(fnrm[-1])

## make a table
forcetot=0.0

with open('Forces.tex','w') as fout:
  lineout=r'''%% Table automatically generated by make_table.py script
\begin{tabular}{c c c c}
    Flap \# & Front Force (N) & Back Force (N) & Net Force (N)
    \rule[-1.5ex]{0pt}{0pt}\
    \\
    \hline'''
  fout.write(lineout)

  for iset in range(int(len(fdirlist)/2)):
    front=force_data[iset*2]
    back=force_data[iset*2+1]
    net=front+back
    forcetot += net

    lineout = r'''
    {:2d} & {:6.4f} & {:6.4f} & {:6.4f} \\
    \hline'''.format(iset+1,front,back,net)

    ## write table begin  \rule adds a buffer space below the title to fit the fraction
    #print(lineout)
    fout.write(lineout)

  ## include the totala force
  lineout = r'''
    Total &  &  & {:6.4f} \\
    \hline'''.format(forcetot)
  fout.write(lineout)

  ## table end
  lineout=r'''
\end{tabular}'''
  fout.write(lineout+"\n")


######################################
##
## plot everything together
##
######################################

plt.title('Force-X vs Time')
plt.xlabel('Time (s)')
plt.ylabel('Force (N)')
plt.tight_layout()
plt.legend(loc='lower center')
#plt.show()
plt.savefig('./images/force-X.png')
plt.clf()


