# state file generated using paraview version 5.8.0

# ----------------------------------------------------------------
# setup views used in the visualization
# ----------------------------------------------------------------
# trace generated using paraview version 5.8.0
#
# To ensure correct image size when batch processing, please search 
# for and uncomment the line `# renderView*.ViewSize = [*,*]`

#### import the simple module from the paraview
from paraview.simple import *
#### disable automatic camera reset on 'Show'
paraview.simple._DisableFirstRenderCameraReset()

# Create a new 'Render View'
renderView1 = CreateView('RenderView')
renderView1.ViewSize = [1920, 1080]
renderView1.AxesGrid = 'GridAxes3DActor'
renderView1.CenterOfRotation = [2.400247573852539, -0.6058766543865204, 0.2697744071483612]
renderView1.StereoType = 'Crystal Eyes'
#renderView1.CameraPosition = [2.8241009662987713, -8.652212958913832, 0.2864114847647066]
renderView1.CameraPosition = [2.8241009662987713, -8.652212958913832, 0.0]
renderView1.CameraFocalPoint = [2.8148041940368578, 41.095150224339704, 0.2413772781460205]
renderView1.CameraViewUp = [0.012727552846648784, 0.0009075629869591196, 0.9999185895501497]
renderView1.CameraFocalDisk = 1.0
renderView1.CameraParallelScale = 12.875570536003433

SetActiveView(None)

SetActiveView(None)

imgpath='./images/'
from pathlib import Path
Path(imgpath).mkdir(parents=True, exist_ok=True)

magenta= [1.0, 0.0, 1.0]
black  = [0.0, 0.0, 0.0]
white  = [1.0, 1.0, 1.0]

fontsize = 32

# ----------------------------------------------------------------
# setup view layouts
# ----------------------------------------------------------------

# create new layout object 'Layout #1'
layout1 = CreateLayout(name='Layout #1')
layout1.AssignView(0, renderView1)

# ----------------------------------------------------------------
# restore active view
SetActiveView(renderView1)
# ----------------------------------------------------------------

# ----------------------------------------------------------------
# script to grab block information
# ----------------------------------------------------------------

def getBlockIndices(compositeDataInformation, index=0):

    localDict = {}

    if compositeDataInformation.GetDataIsMultiPiece():
        index += compositeDataInformation.GetNumberOfChildren()
    else:
        if compositeDataInformation.GetDataIsComposite():
            for i in range(compositeDataInformation.GetNumberOfChildren()):
                index += 1
                _blockName = compositeDataInformation.GetName(i)
                localDict[_blockName] = index
                leafDict, index = getBlockIndices(compositeDataInformation.GetDataInformation(i).GetCompositeDataInformation(), index)
                localDict.update(leafDict)
    return localDict, index


# create a new 'OpenFOAMReader'
import os,sys
import numpy as np

cwd=os.getcwd()
casename=os.path.basename(cwd)

itank=0
yshift=0.0
if 'tank' in casename:
  itank=1
  yshift=0.15

ireflectz=1
if '15deg-pitch' in casename:
    pitchdeg=-15.0
if '30deg-pitch' in casename:
    pitchdeg=-30.0
if '35deg-pitch' in casename:
    pitchdeg=-35.0
if '40deg-pitch' in casename:
    pitchdeg=-40.0
if '45deg-pitch' in casename:
    pitchdeg=-45.0
if '60deg-pitch' in casename:
    pitchdeg=-60.0
if '15deg-yaw' in casename:
    ireflectz=0
    yawdeg=-15.0
if '30deg-yaw' in casename:
    ireflectz=0
    yawdeg=-30.0

# ----------------------------------------------------------------
# setup the data processing pipelines
# ----------------------------------------------------------------

# create a new 'Plane'  source for streamlines
if itank == 1:
  ## ## slanted plane at back paddles
  ## streamSource = Plane()
  ## streamSource.Origin = [5.0, 0.0, 0.0]
  ## streamSource.Point1 = [3.0, -1.25, 0.0]
  ## streamSource.Point2 = [5.0, 0.0, -0.75]
  ## streamSource.XResolution = 5
  ## streamSource.YResolution = 5

  ## ellipse around tank
  cylList=[]
  for icyl in range(5):
    # create a new 'Cylinder'
    cylname='Cylinder{}'.format(icyl+1)

    cyc_centy=0.5+1.0*float(icyl)

    cylinder = Cylinder(registrationName=cylname)
    cylinder.Resolution = 10
    cylinder.Center = [0.0, cyc_centy, 0.0]
    cylinder.Capping = 0
    ## fix name
    RenameSource(cylname, cylinder)\
    ## save list for appending later
    cylList.append(cylinder)

  ## join all cylinders
  # create a new 'Append Geometry'
  appendGeometry1 = AppendGeometry(registrationName='AppendGeometry1', Input=cylList)
  #streamSource = AppendGeometry(registrationName='AppendGeometry1', Input=cylList)

  ## scale it to best wrap tank
  streamSource = Transform(registrationName='Transform1', Input=appendGeometry1)
  streamSource.Transform = 'Transform'
  streamSource.Transform.Translate = [2.45, 0.15, 0.0]
  streamSource.Transform.Rotate = [-90.0, 0.0, 0.0]
  streamSource.Transform.Scale = [5.5, 0.1, 2.0]
else:
  ## horizontal plane cutting through paddles
  if 'deg-yaw' in casename:
      plane1=Plane()
      plane1.Origin = [0.0, -0.33,  0.5]
      plane1.Point1 = [0.0, -0.33, -0.5]
      plane1.Point2 = [5.0, -0.33,  0.5]
      plane1.XResolution = 10
      plane1.YResolution = 5
      
      # Rotate it
      transform1 = Transform(Input=plane1)
      transform1.Transform = 'Transform'
      transform1.Transform.Rotate = [0.0, yawdeg, 0.0]

      theta=yawdeg*np.pi/180.0
      Rx = np.array([[1,0,0],[0,np.cos(theta),-np.sin(theta)],[0, np.sin(theta), np.cos(theta)]])
      Ry = np.array([[np.cos(theta),0,np.sin(theta)],[0,1,0],[-np.sin(theta), 0, np.cos(theta)]])
      Rz = np.array([[np.cos(theta), -np.sin(theta),0],[np.sin(theta), np.cos(theta),0],[0,0,1]])
      ## doing y rotation here
      R=Ry

      ## rotation center
      xcent = np.array([2.35, 0.15, 0.0])
      x0 = np.array(plane1.Origin)
      #xvec = xcent - x0
      xvec = xcent 
      shift = xvec - np.dot(Ry,xvec)
      transform1.Transform.Translate = shift

      streamSource=transform1
  elif 'deg-pitch' in casename:
      plane1=Plane()
      plane1.Origin = [0.0, -0.33,  0.0]
      plane1.Point1 = [0.0, -0.33, -0.5]
      plane1.Point2 = [5.0, -0.33,  0.0]
      plane1.XResolution = 5
      plane1.YResolution = 5
      
      # Rotate it
      transform1 = Transform(Input=plane1)
      transform1.Transform = 'Transform'
      transform1.Transform.Rotate = [0.0, 0.0, pitchdeg]

      #theta=yawdeg*np.pi/180.0
      #Rx = np.array([[1,0,0],[0,np.cos(theta),-np.sin(theta)],[0, np.sin(theta), np.cos(theta)]])
      #Ry = np.array([[np.cos(theta),0,np.sin(theta)],[0,1,0],[-np.sin(theta), 0, np.cos(theta)]])
      #Rz = np.array([[np.cos(theta), -np.sin(theta),0],[np.sin(theta), np.cos(theta),0],[0,0,1]])
      ### doing y rotation here
      #R=Ry

      ### rotation center
      #xcent = np.array([2.35, 0.15, 0.0])
      #x0 = np.array(plane1.Origin)
      ##xvec = xcent - x0
      #xvec = xcent 
      #shift = xvec - np.dot(Ry,xvec)
      #transform1.Transform.Translate = shift

      streamSource=transform1
  else:
      streamSource = Plane()
      streamSource.Origin = [0.0, -0.33,  0.0]
      streamSource.Point1 = [0.0, -0.33, -0.5]
      streamSource.Point2 = [5.0, -0.33,  0.0]
      streamSource.XResolution = 5
      streamSource.YResolution = 5

# create a new 'OpenFOAMReader'
baselinefoam = OpenFOAMReader(FileName='./'+casename+'.foam')
# rename source object
RenameSource('baseline.foam', baselinefoam)
#baselinefoam = FindSource('baseline.foam')

## load all regions
baselinefoam.MeshRegions.SelectAll()

## need to activate it to set cdi
Show(baselinefoam, renderView1)
cdi=baselinefoam.GetDataInformation().GetCompositeDataInformation()
Hide(baselinefoam, renderView1)
## get block listing
blockinfo,nblocks=getBlockIndices(cdi)

## undo scaling if this is a scaled run
if '_10x' in casename:
    xscale=0.1
elif '_0.1x' in casename:
    xscale=10.0
## make the translation the new baseline for the rest of the script
if '_10x' in casename or '_0.1x' in casename:
    baselinefoamOrig=baselinefoam

    # create a new 'Calculator'
    # stupid workaround to prevent U from scaling with transform
    calculatorA = Calculator(Input=baselinefoamOrig)
    calculatorA.Function = 'U'
    calculatorA.AttributeType = 'Point Data'
    calculatorB = Calculator(Input=calculatorA)
    calculatorB.Function = 'U'
    calculatorB.AttributeType = 'Cell Data'

    baselinefoam = Transform(calculatorB)
    baselinefoam.Transform = 'Transform'
    baselinefoam.Transform.Scale = [xscale,xscale,xscale]
    # Properties modified on transform1.Transform
    baselinefoam.TransformAllInputVectors = 0
    Hide(baselinefoam, renderView1)

# create Device 'Extract Block'
device = ExtractBlock(Input=baselinefoam)
idxList=[]
idxList.append(blockinfo['MOWT'])
#idxList = [value for key, value in blockinfo.items() if '_front' in key ]
## also add paddle fronts
for key, value in blockinfo.items():
  if '_front' in key:
    idxList.append(value)
if itank == 1:
    idxList.append(blockinfo['slip'])
device.BlockIndices = idxList
RenameSource('Device', device)

# Reflect it
if ireflectz == 1:
    reflectDevice = Reflect(Input=device)
    reflectDevice.Plane = 'Z Max'
else:
    reflectDevice=device

# create Fluid 'Extract Block'
fluid = ExtractBlock(Input=baselinefoam)
idx = blockinfo['internalMesh']
fluid.BlockIndices = [idx]
RenameSource('Fluid', fluid)



# create a new 'Stream Tracer With Custom Source' using fluid and plane source
streamTracerWithCustomSource1 = StreamTracerWithCustomSource(Input=fluid,
    SeedSource=streamSource)
streamTracerWithCustomSource1.Vectors = ['POINTS', 'U']
streamTracerWithCustomSource1.MaximumStreamlineLength = 25.72000026702881

# reflect it
if ireflectz==1:
    reflectStream = Reflect(Input=streamTracerWithCustomSource1)
    reflectStream.Plane = 'Z Max'
else:
    reflectStream = streamTracerWithCustomSource1

# create a new 'Ribbon'
ribbon1 = Ribbon(Input=streamTracerWithCustomSource1)
ribbon1.Scalars = ['POINTS', 'AngularVelocity']
ribbon1.Vectors = ['POINTS', 'Vorticity']
ribbon1.Width = 0.01

# create a new 'Reflect'
reflectRibbon = Reflect(Input=ribbon1)
reflectRibbon.Plane = 'Z Max'

# create a new 'Glyph' on ribbons
glyph1 = Glyph(Input=reflectRibbon,
    GlyphType='Arrow')
glyph1.OrientationArray = ['POINTS', 'U']
glyph1.ScaleArray = ['POINTS', 'U']
glyph1.ScaleFactor = 0.25
glyph1.GlyphTransform = 'Transform2'
glyph1.GlyphMode = 'Uniform Spatial Distribution (Surface Sampling)'
glyph1.MaximumNumberOfSamplePoints = 500




# ----------------------------------------------------------------
# setup the visualization in view 'renderView1'
# ----------------------------------------------------------------

# show data from reflectDevice
reflectDeviceDisplay = Show(reflectDevice, renderView1, 'UnstructuredGridRepresentation')

## Tune the pressure legend
pmin = -1.5
pmax =  2.1

# get color transfer function/color map for 'p'
pLUT = GetColorTransferFunction('p')
pLUT.AutomaticRescaleRangeMode = 'Never'

# get opacity transfer function/opacity map for 'p'
pPWF = GetOpacityTransferFunction('p')

# Rescale transfer function
pLUT.RescaleTransferFunction(pmin, pmax)

# Rescale transfer function
pPWF.RescaleTransferFunction(pmin, pmax)

pLUT.ApplyPreset('Cool to Warm', True)

# trace defaults for the display properties.
reflectDeviceDisplay.Representation = 'Surface'
reflectDeviceDisplay.ColorArrayName = ['POINTS', 'p']
reflectDeviceDisplay.LookupTable = pLUT
reflectDeviceDisplay.OSPRayScaleArray = 'p'

# get color legend/bar for pLUT in view renderView1
pLUTColorBar = GetScalarBar(pLUT, renderView1)
pLUTColorBar.WindowLocation = 'AnyLocation'

pLUTColorBar.Title = 'Pressure'
pLUTColorBar.ComponentTitle = ''

pLUTColorBar.Orientation = 'Horizontal'
legendLength=0.5
xpos = (1.0-legendLength)/2.0
ypos=0.82

pLUTColorBar.Position = [xpos,ypos]
pLUTColorBar.ScalarBarLength = legendLength
pLUTColorBar.Visibility = 1

pLUTColorBar.UseCustomLabels = 1
pLUTColorBar.CustomLabels = np.linspace(pmin,pmax,5)

pLUTColorBar.TitleFontSize = fontsize
pLUTColorBar.LabelFontSize = fontsize
pLUTColorBar.ScalarBarThickness = fontsize



# show data from glyph1
glyph1Display = Show(glyph1, renderView1, 'GeometryRepresentation')

# trace defaults for the display properties.
glyph1Display.Representation = 'Surface'
glyph1Display.ColorArrayName = ['POINTS', '']
glyph1Display.OSPRayScaleArray = 'p'
glyph1Display.OSPRayScaleFunction = 'PiecewiseFunction'


# show data from reflectStream
reflectStreamDisplay = Show(reflectStream, renderView1, 'UnstructuredGridRepresentation')



## color slice by velocity
vmin=0.0
vmax=2.0

# get color transfer function/color map for 'Velocity'
velocityLUT = GetColorTransferFunction('Velocity')
velocityLUT.AutomaticRescaleRangeMode = 'Never'
#velocityLUT.ScalarRangeInitialized = 1

# get opacity transfer function/opacity map for 'Velocity'
velocityPWF = GetOpacityTransferFunction('Velocity')

# Rescale transfer function
velocityLUT.RescaleTransferFunction(vmin, vmax)

# Rescale transfer function
velocityPWF.RescaleTransferFunction(vmin, vmax)

velocityLUT.ApplyPreset('Viridis (matplotlib)', True)


# trace defaults for the display properties.
reflectStreamDisplay.Representation = 'Surface'
reflectStreamDisplay.ColorArrayName = ['POINTS', 'U']
reflectStreamDisplay.LookupTable = velocityLUT

# get color legend/bar for velocityLUT in view renderView1
velocityLUTColorBar = GetScalarBar(velocityLUT, renderView1)
velocityLUTColorBar.WindowLocation = 'AnyLocation'

velocityLUTColorBar.Title = 'Velocity'
velocityLUTColorBar.ComponentTitle = 'Magnitude'

velocityLUTColorBar.Orientation = 'Horizontal'
legendLength=0.5
xpos = (1.0-legendLength)/2.0
ypos=0.01

velocityLUTColorBar.Position = [xpos,ypos]
velocityLUTColorBar.ScalarBarLength = legendLength

# set color bar visibility
velocityLUTColorBar.Visibility = 1

# Properties modified on velocityLUTColorBar
velocityLUTColorBar.UseCustomLabels = 1
velocityLUTColorBar.CustomLabels = np.linspace(vmin,vmax,5)

velocityLUTColorBar.TitleFontSize = fontsize
velocityLUTColorBar.LabelFontSize = fontsize
velocityLUTColorBar.ScalarBarThickness = fontsize

if 'mirror' in casename:
  device.BlockIndices = idxList[1:]  ## remove MOWT


# ----------------------------------------------------------------
# setup color maps and opacity mapes used in the visualization
# note: the Get..() functions create a new object, if needed
# ----------------------------------------------------------------

# ----------------------------------------------------------------
# finally, restore active source
SetActiveSource(reflectStream)
# ----------------------------------------------------------------

## SAVE IMAGE
SaveScreenshot(imgpath+'streamlines.png', renderView1, ImageResolution=[1920, 1080],
    FontScaling='Do not scale fonts',  # font sizes are specified at 32
    TransparentBackground=0,
    OverrideColorPalette='PrintBackground')

#if 'mirror' in casename:
#  device.BlockIndices = idxList

#
#renderView1.CenterOfRotation = [2.3499999046325684, -2.4999999999999862, 0.24325000593671575]
#renderView1.CameraPosition = [2.5152672595046077, -1.5219613597156005, 6.7251781938166495]
#renderView1.CameraFocalPoint = [2.5152672595046077, -1.5219613597156005, -41.968545220391206]
#renderView1.CameraViewUp = [0, 1, 0]
#renderView1.CameraFocalDisk = 1.0
#renderView1.CameraParallelScale = 12.60286299655153
#
#SaveScreenshot(imgpath+'streamlines-side.png', renderView1, ImageResolution=[1920, 1080],
#    FontScaling='Do not scale fonts',  # font sizes are specified at 32
#    TransparentBackground=0,
#    OverrideColorPalette='PrintBackground')
#
